@@ -1,4 +1,5 @@
 # -*- coding: utf8 -*-
+from collections import Mapping, Sequence
 
 from handlers.json_handler import JsonHandler
 from handlers.dict_handler import DictHandler
@@ -6,6 +7,7 @@ from handlers.yaml_handler import YamlHandler
 from handlers.file_handler import FileHandler
 from handlers.ini_handler import IniHandler
 
+
 SENTINEL = object()
 
 
@@ -31,28 +33,45 @@ class Kaptan(object):
         self.configuration_data = self.handler.load(value)
         return self
 
-    def get(self, key, default=SENTINEL):
+    def _get(self, key):
         current_data = self.configuration_data
+
         for chunk in key.split('.'):
-            try:
-                current_data = current_data.get(chunk, {})
-            except AttributeError as error:
-                if isinstance(current_data, list):
-                    try:
-                        chunk = int(chunk)
-                    except ValueError:
-                        raise error
+            if isinstance(current_data, Mapping):
+                current_data = current_data[chunk]
+            elif isinstance(current_data, Sequence):
+                chunk = int(chunk)
 
-                    return current_data[chunk]
-                else:
-                    # for multi dimensional configs like foo.bar.baz
-                    return self.__handle_default_value(key, default)
-
-        if current_data == {}:
-            return self.__handle_default_value(key, default)
+                current_data = current_data[chunk]
+            else:
+                # A scalar type has been found
+                return current_data
 
         return current_data
 
+    def get(self, key, default=SENTINEL):
+        try:
+            try:
+                return self._get(key)
+            except (KeyError):
+                raise KeyError(key)
+            except (ValueError):
+                raise ValueError("Sequence index not an integer")
+            except (IndexError):
+                raise IndexError("Sequence index out of range")
+        except (KeyError, ValueError, IndexError):
+            if default is not SENTINEL:
+                return default
+            raise
+
+    def export(self, handler=None):
+        if not handler:
+            handler_class = self.handler
+        else:
+            handler_class = self.HANDLER_MAP[handler]()
+
+        return handler_class.dump(self.configuration_data)
+
     def __handle_default_value(self, key, default):
         if default == SENTINEL:
             raise KeyError(key)
@@ -66,4 +85,3 @@ class Kaptan(object):
             handler_class = self.HANDLER_MAP[handler]()
 
         return handler_class.dump(self.configuration_data)
-
